@@ -4,7 +4,7 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
 # setup our tests and etc
 use Test::Block qw( $Plan );
@@ -17,12 +17,9 @@ use base qw( Exporter );
 our @EXPORT = qw( is_apocalypse_here ); ## no critic ( ProhibitAutomaticExportation )
 
 sub is_apocalypse_here {
-	# arrayref of tests to skip/use/etc
-	my $tests = shift;
-
 	# should we even run those tests?
-	if ( ! $ENV{TEST_AUTHOR} ) {
-		plan skip_all => 'Author test. Sent $ENV{TEST_AUTHOR} to a true value to run.';
+	unless ( $ENV{RELEASE_TESTING} or $ENV{AUTOMATED_TESTING} ) {
+		plan skip_all => 'Author test. Please set $ENV{RELEASE_TESTING} to a true value to run.';
 	} else {
 		plan 'no_plan';
 
@@ -30,11 +27,67 @@ sub is_apocalypse_here {
 		eval "use Test::NoWarnings";		## no critic ( ProhibitStringyEval )
 	}
 
+	# The options hash
+	my %opt;
+
+	# Support passing in a hash ref or a regular hash
+	if ( ( @_ & 1 ) and ref $_[0] and ref( $_[0] ) eq 'HASH' ) {
+		%opt = %{ $_[0] };
+	} else {
+		# Sanity checking
+		if ( @_ & 1 ) {
+			die 'The sub is_apocalypse_here() requires an even number of options';
+		}
+
+		%opt = @_;
+	}
+
+	# lowercase keys
+	%opt = map { lc($_) => $opt{$_} } keys %opt;
+
+	# setup the "allow/deny" tests
+	if ( exists $opt{'allow'} and exists $opt{'deny'} ) {
+		die 'Unable to use "allow" and "deny" at the same time!';
+	}
+	foreach my $type ( qw( allow deny ) ) {
+		if ( ! exists $opt{ $type } or ! defined $opt{ $type } ) {
+			# Don't set anything
+			delete $opt{ $type } if exists $opt{ $type };
+		} else {
+			if ( ! ref $opt{ $type } ) {
+				# convert it to a qr// regex?
+				eval { $opt{ $type } = qr/$opt{ $type }/i };
+				if ( $@ ) {
+					die "Unable to compile the '$type' regex: $@";
+				}
+			} elsif ( ref( $opt{ $type } ) ne 'Regexp' ) {
+				die "The '$type' option is not a regexp!";
+			}
+		}
+	}
+
 	# loop through our plugins
 	foreach my $t ( __PACKAGE__->plugins() ) {	## no critic ( RequireExplicitInclusion )
 		# localize the stuff
 		local $Plan;
 
+		# Do we want this test?
+		if ( exists $opt{'allow'} ) {
+			if ( $t =~ /^Test::Apocalypse::(.+)$/ ) {
+				if ( $1 !~ $opt{'allow'} ) {
+					diag( "Skipping '$t' tests..." );
+					next;
+				}
+			}
+		} elsif ( exists $opt{'deny'} ) {
+			if ( $t =~ /^Test::Apocalypse::(.+)$/ ) {
+				if ( $1 =~ $opt{'deny'} ) {
+					diag( "Skipping '$t' tests..." );
+					next;
+				}
+			}
+		}
+
 		# do nasty override of Test::Builder::plan
 		my $oldplan = \&Test::Builder::plan;		## no critic ( ProhibitCallsToUnexportedSubs )
 		my $newplan = sub {
@@ -57,16 +110,16 @@ sub is_apocalypse_here {
 			return 1;
 		};
 
-		no warnings 'redefine'; no strict 'refs';
+		no warnings 'redefine'; no strict 'refs';	## no critic ( ProhibitNoStrict )
 		*{'Test::Builder::plan'} = $newplan;
 
 		# run it!
 		use warnings; use strict;
-		diag( "running $t tests..." );
+		diag( "Running '$t' tests..." );
 		$t->do_test();
 
 		# revert the override
-		no warnings 'redefine'; no strict 'refs';
+		no warnings 'redefine'; no strict 'refs';	## no critic ( ProhibitNoStrict )
 		*{'Test::Builder::plan'} = $oldplan;
 	}
 
@@ -77,7 +130,7 @@ sub is_apocalypse_here {
 1;
 __END__
 
-=for stopwords APOCAL AUTHORs AnnoCPAN CPAN RT al backend debian distro distros dists env hackish plugins testsuite yml
+=for stopwords APOCAL AUTHORs AnnoCPAN CPAN RT al backend debian distro distros dists env hackish plugins testsuite yml pm yay unicode blog precompiled CPANTS
 
 =head1 NAME
 
@@ -109,8 +162,9 @@ the tons of t/foo.t scripts + managing them in every distro. I thought it would
 one module and toss it on CPAN :) That way, every time I update this module all of my dists would be magically
 updated!
 
-This module respects the TEST_AUTHOR env variable, if it is not set it will skip the entire testsuite. Normally
-end-users should not run it; but you can if you want to see how bad my dists are, ha!
+This module respects the RELEASE_TESTING env variable, if it is not set it will skip the entire testsuite. Normally
+end-users should not run it; but you can if you want to see how bad my dists are, ha! The scheme is exactly the same
+as the one Alias proposed in L<Test::XT> and in his blog post, L<http://use.perl.org/~Alias/journal/38822>.
 
 This module uses L<Module::Pluggable> to have custom "backends" that process various tests. We wrap them in a hackish
 L<Test::Block> block per-plugin and it seems to work nicely. If you want to write your own, it should be a breeze
@@ -125,7 +179,52 @@ you can do this:
 
 	perl Build.PL			# sets up the dist ( duh, hah )
 	./Build dist			# makes the tarball ( so certain plugins can process it )
-	TEST_AUTHOR=1 ./Build test	# runs the testsuite!
+	RELEASE_TESTING=1 ./Build test	# runs the testsuite!
+
+=head1 Methods
+
+=head2 is_apocalypse_here()
+
+This is the main entry point for this testsuite. By default, it runs every plugin in the testsuite. You can enable/disable
+specific plugins if you desire. It accepts a single argument: a hashref or a hash. It can contain various options, but as of
+now it only supports two options. If you try to use allow and deny at the same time, this module will throw an exception.
+
+=head3 allow
+
+Setting "allow" to a string or a precompiled regex will run only the plugins that match the regex. If passed a string, this module
+will compile it via C<qr/$str/i>.
+
+	# run only the EOL test and disable all other tests
+	is_apocalypse_here( {
+		allow	=> qr/^EOL$/,
+	} );
+
+	# run all "dist" tests
+	is_apocalypse_here( {
+		allow	=> 'dist',
+	} );
+
+=head3 deny
+
+Setting "deny" to a string or a precompiled regex will not run the plugins that match the regex. If passed a string, this module
+will compile it via C<qr/$str/i>.
+
+	# disable Pod_Coverage test and enable all other tests
+	is_apocalypse_here( {
+		deny	=> qr/^Pod_Coverage$/,
+	} );
+
+	# disable all pod tests
+	is_apocalypse_here( {
+		deny	=> 'pod',
+	} );
+
+=head2 plugins()
+
+Since this module uses L<Module::Pluggable> you can use this method on the package to find out what plugins are available. Handy if you need
+to know what plugins to skip, for example.
+
+	my @tests = Test::Apocalypse->plugins;
 
 =head1 EXPORT
 
@@ -143,19 +242,11 @@ Automatically exports the "is_apocalypse_here" sub.
 
 Do we have SYNOPSIS, ABSTRACT, SUPPORT, etc sections? ( PerlCritic can do that! Need to investigate more... )
 
-=item * Use Test::AutoLoader to check for .al files
-
-Br0ken install at this time...
-
 =item * Help with version updates automatically
 
 This little snippet helps a lot, I was wondering if I could integrate it into the testsuite hah!
 
-	find -name '*.pm' | grep -v /blib/ | xargs sed -i "s/\$VERSION = '[^']\+\?';/\$VERSION = '0.04';/"
-
-=item * Help Test::CheckChanges author for more formats
-
-I already filed a ticket, RT#42976 but if others have different formats please contribute!
+	find -name '*.pm' | grep -v /blib/ | xargs sed -i "s/\$VERSION = '[^']\+\?';/\$VERSION = '0.06';/"
 
 =item * Use Test::GreaterVersion to sanity check versions
 
@@ -171,10 +262,6 @@ Br0ken install at this time... ( PerlCritic can do that! Need to investigate mor
 This would be nice, but I'm not sure if I can actually force this on other tests. Otherwise I'll be just making
 sure that the Test::Apocalypse tests is unique, which is worthless to $dist trying to clean itself up...
 
-=item * Use Test::CPAN::Meta
-
-I'm not sure of the difference between this and Test::YAML::Meta but more tests == the better ;)
-
 =item * META.yml checks
 
 We should make sure that the META.yml includes the "repository", "license", and other useful keys!
@@ -183,6 +270,26 @@ We should make sure that the META.yml includes the "repository", "license", and
 
 As always, we should keep up on the "latest" in the perl world and look at other authors for what they are doing.
 
+=item * indirect syntax
+
+We should figure out how to use indirect.pm to detect this deprecated method of coding. There's a L<Perl::Critic> plugin for this, yay!
+
+=item * Test::LatestPrereqs
+
+This looks cool but we need to fiddle with config files? My OutdatedPrereqs test already covers it pretty well...
+
+=item * Test::PPPort
+
+Already implemented as PPPort.pm but it's less invasive than my version, ha!
+
+=item * Test::PureASCII
+
+This rocks, as I don't care about unicode in my perl! ;)
+
+=item * Test::Pod::Content
+
+Maybe this is useful to test my "common" boilerplate POD and make sure they are the "latest", eh?
+
 =back
 
 =head1 SEE ALSO
@@ -199,6 +306,10 @@ You can find documentation for this module with the perldoc command.
 
 =over 4
 
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Test-Apocalypse>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Test-Apocalypse>
@@ -207,18 +318,22 @@ L<http://annocpan.org/dist/Test-Apocalypse>
 
 L<http://cpanratings.perl.org/d/Test-Apocalypse>
 
-=item * RT: CPAN's request tracker
+=item * RT: CPAN's Request Tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Apocalypse>
 
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Test-Apocalypse>
-
-=item * CPAN Testing Service
+=item * CPANTS Kwalitee
 
 L<http://cpants.perl.org/dist/overview/Test-Apocalypse>
 
+=item * CPAN Testers Results
+
+L<http://cpantesters.org/distro/T/Test-Apocalypse.html>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Test-Apocalypse>
+
 =back
 
 =head2 Bugs
@@ -235,7 +350,7 @@ Thanks to jawnsy@cpan.org for the prodding and help in getting this package read
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
