@@ -4,33 +4,46 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
 use Test::More;
-use File::Find::Rule;
 
-# does our stuff!
 sub do_test {
+	my %MODULES = (
+		'File::Find::Rule'	=> '0.32',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
+	# Run the test!
 	plan tests => 1;
 
 	# generate the file list
 	my $rule = File::Find::Rule->new;
 	$rule->grep( qr/\r\n/ );
-	my @files = $rule->in( qw( lib t examples ) );	# FIXME sometimes we don't have examples dir, F:F:R complains!
+	my @files = $rule->in( '.' );
 
-	# FIXME read in MANIFEST.SKIP and use it!
 	# for now, we skip SVN + git stuff
-	@files = grep { $_ !~ /(?:\/\.svn\/|\/\.git\/)/ } @files;
+	# also skip any tarballs
+	@files = grep { $_ !~ /(?:\.svn\/|\.git\/|tar(?:\.gz|\.bz2)?|tgz|zip)/ } @files;
 
 	# test it!
 	if ( scalar @files ) {
-		fail( 'DOS-style newline detected' );
+		fail( 'DOS-style newline detected in the distribution' );
 		foreach my $f ( @files ) {
-			diag( "newline check on $f" );
+			diag( "DOS-style newline found in: $f" );
 		}
 	} else {
-		pass( 'no files have DOS-style newline in it' );
+		pass( 'No files have DOS-style newline in it' );
 	}
 
 	return;
@@ -47,7 +60,7 @@ Test::Apocalypse::DOSnewline - Plugin to detect presence of DOS newlines
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -57,9 +70,9 @@ This plugin detects for the presence of DOS newlines in the dist.
 
 This plugin detects for the presence of DOS newlines in the dist.
 
-=head1 EXPORT
+=head2 do_test()
 
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -71,7 +84,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
