@@ -4,20 +4,41 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
 use Test::More;
-use Module::CPANTS::Analyse;
-use version;
 
-# does our stuff!
 sub do_test {
+	## no critic ( ProhibitAccessOfPrivateData )
+
+	my %MODULES = (
+		'Module::CPANTS::Analyse'	=> '0.85',
+		'version'			=> '0.77',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
+	# Run the test!
 	# the following code was copied/plagarized/transformed from Test::Kwalitee, thanks!
+	# The reason why I didn't just use that module is because it doesn't print the kwalitee or consider extra metrics...
 
 	# init CPANTS with the latest tarball
+	my $tarball = _get_tarball();
+	if ( ! defined $tarball ) {
+		plan skip_all => 'Distribution tarball not found, unable to run CPANTS Kwalitee tests.';
+		return;
+	}
 	my $analyzer = Module::CPANTS::Analyse->new({
-		'dist'	=> get_tarball(),
+		'dist'	=> $tarball,
 	});
 
 	# set the number of tests / run analyzer
@@ -45,7 +66,13 @@ sub do_test {
 			if ( exists $metric->{'is_extra'} and $metric->{'is_extra'} ) {
 				$type = 'EXTRA';
 			}
-			ok( $result, "[$type] $metric->{'name'}" );
+
+			# non-core tests PASS automatically
+			if ( $type eq 'CORE' or $result ) {
+				ok( $result, "[$type] $metric->{'name'}" );
+			} else {
+				pass( "[$type] $metric->{'name'} treated as PASS" );
+			}
 
 			# print more diag if it failed
 			if ( ! $result && $ENV{TEST_VERBOSE} ) {
@@ -73,24 +100,30 @@ sub do_test {
 	diag( "Kwalitee rating: " . sprintf( "%.2f%%", 100 * ( $kwalitee_points / $available_kwalitee ) ) . " [$kwalitee_points / $available_kwalitee]" );
 
 	# That piece of crap dumps files all over :(
-	cleanup_debian_files();
+	_cleanup_debian_files();
 
 	return;
 }
 
-sub get_tarball {
+sub _get_tarball {
 	# get our list of stuff, and try to find the latest tarball
-	opendir( my $dir, '.' ) or die "unable to opendir: $!";
+	opendir( my $dir, '.' ) or die "Unable to opendir: $!";
 	my @dirlist = readdir( $dir );
-	closedir( $dir );
+	closedir( $dir ) or die "Unable to closedir: $!";
 
 	# get the tarballs
-	@dirlist = grep { /\.tar\.gz$/ } @dirlist;
+	@dirlist = grep { /(?:tar(?:\.gz|\.bz2)?|tgz|zip)$/ } @dirlist;
+
+	# short-circuit
+	if ( scalar @dirlist == 0 ) {
+		return;
+	}
 
 	# get the versions
+	## no critic ( ProhibitAccessOfPrivateData )
 	@dirlist = map { [ $_, $_ ] } @dirlist;
 	for ( @dirlist ) {
-		$_->[0] =~ s/^.*\-([^\-]+)\.tar\.gz$/$1/;
+		$_->[0] =~ s/^.*\-([^\-]+)(?:tar(?:\.gz|\.bz2)?|tgz|zip)$/$1/;
 		$_->[0] = version->new( $_->[0] );
 	}
 
@@ -108,7 +141,7 @@ sub get_tarball {
 ## The following files are not named in the MANIFEST file: /home/apoc/workspace/VCS-perl-trunk/VCS-2.12.2/Debian_CPANTS.txt
 ## Looks like you failed 1 test of 1.
 #t/a_manifest.............. Dubious, test returned 1 (wstat 256, 0x100)
-sub cleanup_debian_files {
+sub _cleanup_debian_files {
 	foreach my $file ( qw( Debian_CPANTS.txt ../Debian_CPANTS.txt ) ) {
 		if ( -e $file and -f _ ) {
 			my $status = unlink( $file );
@@ -123,13 +156,16 @@ sub cleanup_debian_files {
 
 1;
 __END__
+
+=for stopwords kwalitee
+
 =head1 NAME
 
 Test::Apocalypse::Kwalitee - Plugin for Test::Kwalitee
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -137,11 +173,11 @@ Encapsulates Test::Kwalitee functionality.
 
 =head1 DESCRIPTION
 
-Encapsulates Test::Kwalitee functionality.
+Encapsulates Test::Kwalitee functionality. This plugin also processes the extra metrics, and prints out the kwalitee as a diag() for info.
 
-=head1 EXPORT
+=head2 do_test()
 
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -155,7 +191,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
