@@ -4,25 +4,37 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
 use Test::More;
-use YAML;
-use CPANPLUS::Backend;
-use CPANPLUS::Configure;
-use version;
-use Module::CoreList;
 
-# does our stuff!
 sub do_test {
+	my %MODULES = (
+		'YAML'			=> '0.70',
+		'CPANPLUS'		=> '0.90',
+		'version'		=> '0.77',
+		'Module::CoreList'	=> '2.23',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
+	# Run the test!
 	# does META.yml exist?
 	if ( -e 'META.yml' and -f _ ) {
-		load_yml( 'META.yml' );
+		_load_yml( 'META.yml' );
 	} else {
 		# maybe one directory up?
 		if ( -e '../META.yml' and -f _ ) {
-			load_yml( '../META.yml' );
+			_load_yml( '../META.yml' );
 		} else {
 			plan tests => 1;
 			fail( 'META.yml is missing, unable to process it!' );
@@ -32,8 +44,7 @@ sub do_test {
 	return;
 }
 
-# main entry point
-sub load_yml {
+sub _load_yml {
 	# we'll load a file
 	my $file = shift;
 
@@ -49,10 +60,13 @@ sub load_yml {
 	}
 
 	# massage the data
+	## no critic ( ProhibitAccessOfPrivateData )
 	$data = $data->{'requires'};
 	delete $data->{'perl'} if exists $data->{'perl'};
 
 	# init the backend ( and set some options )
+	require CPANPLUS::Configure;
+	require CPANPLUS::Backend;
 	my $cpanconfig = CPANPLUS::Configure->new;
 	$cpanconfig->set_conf( 'verbose' => 0 );
 	$cpanconfig->set_conf( 'no_update' => 1 );
@@ -67,18 +81,22 @@ sub load_yml {
 	}
 
 	# Okay, how many prereqs do we have?
-	plan tests => scalar keys %$data;
+	if ( scalar keys %$data > 0 ) {
+		plan tests => scalar keys %$data;
+	} else {
+		plan skip_all => "No prereqs found in META.yml";
+	}
 
 	# analyze every one of them!
 	foreach my $prereq ( keys %$data ) {
-		check_cpan( $cpanplus, $prereq, $data->{ $prereq } );
+		_check_cpan( $cpanplus, $prereq, $data->{ $prereq } );
 	}
 
 	return;
 }
 
 # checks a prereq against CPAN
-sub check_cpan {
+sub _check_cpan {
 	my $backend = shift;
 	my $prereq = shift;
 	my $version = shift;
@@ -94,7 +112,7 @@ sub check_cpan {
 
 		# Does the prereq have funky characters that we're unable to process now?
 		if ( $version =~ /[<>=,!]+/ ) {
-			# FIXME simplistic style of parsing
+			# simple style of parsing, may blow up in the future!
 			my @versions = split( ',', $version );
 
 			# sort them by version, descending
@@ -135,7 +153,7 @@ Test::Apocalypse::OutdatedPrereqs - Plugin to detect outdated prereqs
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -145,9 +163,9 @@ This plugin detects outdated prereqs in F<META.yml> specified relative to CPAN.
 
 This plugin detects outdated prereqs in F<META.yml> specified relative to CPAN.
 
-=head1 EXPORT
+=head2 do_test()
 
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -159,7 +177,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
