@@ -4,15 +4,28 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
 use Test::More;
-use version;
-use Devel::PPPort qw( WriteFile );
 
-# does our stuff!
 sub do_test {
+	my %MODULES = (
+		'version'	=> '0.77',
+		'Devel::PPPort'	=> '3.19',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
+	# Run the test!
 	plan tests => 2;
 
 	# do we have an existing ppport.h file?
@@ -79,13 +92,16 @@ sub do_test {
 
 1;
 __END__
+
+=for stopwords ppport
+
 =head1 NAME
 
 Test::Apocalypse::PPPort - Plugin to test for Devel::PPPort warnings
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -93,11 +109,11 @@ Plugin to test for Devel::PPPort warnings.
 
 =head1 DESCRIPTION
 
-Plugin to test for Devel::PPPort warnings.
+Plugin to test for Devel::PPPort warnings. It automatically updates your bundled ppport.h file to the latest provided by L<Devel::PPPort>!
 
-=head1 EXPORT
+=head2 do_test()
 
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -111,7 +127,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
