@@ -4,24 +4,33 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
 use Test::More;
-use Perl::Metrics::Simple;
 
-# Set some constants
-BEGIN {
-	if ( ! defined &NUMDISPLAY ) { *NUMDISPLAY = sub () { 10 } }
-}
-
-# does our stuff!
 sub do_test {
-	# do it!
+	my %MODULES = (
+		'Perl::Metrics::Simple'	=> '0.13',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
+	# Run the test!
 	plan tests => 1;
 	my $analzyer = Perl::Metrics::Simple->new;
 	my $analysis = $analzyer->analyze_files( 'lib/' );
+	my $numdisplay = 10;
 
+	## no critic ( ProhibitAccessOfPrivateData )
 	if ( ok( $analysis->file_count(), 'analyzed at least one file' ) ) {
 		# only print extra stuff if necessary
 		if ( $ENV{TEST_VERBOSE} ) {
@@ -40,18 +49,18 @@ sub do_test {
 			diag( ' Standard Deviation: lines(' . $summary_stats->{sub_length}->{standard_deviation} . ') McCabe(' . $summary_stats->{sub_complexity}->{standard_deviation} . ')' );
 			diag( ' Median: lines(' . $summary_stats->{sub_length}->{median} . ') McCabe(' . $summary_stats->{sub_complexity}->{median} . ')' );
 
-			diag( "-- Top" . NUMDISPLAY() . " subroutines by McCabe Complexity --" );
+			diag( "-- Top$numdisplay subroutines by McCabe Complexity --" );
 			my @sorted_subs = sort { $b->{'mccabe_complexity'} <=> $a->{'mccabe_complexity'} } @{ $analysis->subs };
-			foreach my $i ( 0 .. ( NUMDISPLAY() - 1 ) ) {
+			foreach my $i ( 0 .. ( $numdisplay - 1 ) ) {
 				diag( ' ' . $sorted_subs[$i]->{'path'} . ':' . $sorted_subs[$i]->{'name'} . ' ->' .
 					' McCabe(' . $sorted_subs[$i]->{'mccabe_complexity'} . ')' .
 					' lines(' . $sorted_subs[$i]->{'lines'} . ')'
 				);
 			}
 
-			diag( "-- Top" . NUMDISPLAY() . " subroutines by lines --" );
+			diag( "-- Top$numdisplay subroutines by lines --" );
 			@sorted_subs = sort { $b->{'lines'} <=> $a->{'lines'} } @sorted_subs;
-			foreach my $i ( 0 .. ( NUMDISPLAY() - 1 ) ) {
+			foreach my $i ( 0 .. ( $numdisplay - 1 ) ) {
 				diag( ' ' . $sorted_subs[$i]->{'path'} . ':' . $sorted_subs[$i]->{'name'} . ' ->' .
 					' lines(' . $sorted_subs[$i]->{'lines'} . ')' .
 					' McCabe(' . $sorted_subs[$i]->{'mccabe_complexity'} . ')'
@@ -75,7 +84,7 @@ Test::Apocalypse::PerlMetrics - Plugin for Perl::Metrics::Simple
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -83,11 +92,11 @@ Encapsulates Perl::Metrics::Simple functionality.
 
 =head1 DESCRIPTION
 
-Encapsulates Perl::Metrics::Simple functionality.
+Encapsulates Perl::Metrics::Simple functionality. Enable TEST_VERBOSE to get a diag() output of some metrics.
 
-=head1 EXPORT
+=head2 do_test()
 
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -101,7 +110,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
