@@ -4,17 +4,28 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
 use Test::More;
-use Test::Pod::Coverage;
 
-# does our stuff!
 sub do_test {
-	# FIXME not used now
-	#all_pod_coverage_ok( 'lib/');
-	plan skip_all => 'not done yet';
+	my %MODULES = (
+		'Test::Pod::Coverage'	=> '1.08',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
+	# Run the test!
+	all_pod_coverage_ok( 'lib/');
 
 	return;
 }
@@ -27,7 +38,7 @@ Test::Apocalypse::Pod_Coverage - Plugin for Test::Pod::Coverage
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -37,11 +48,9 @@ Encapsulates Test::Pod::Coverage functionality.
 
 Encapsulates Test::Pod::Coverage functionality.
 
-NOTE: This module is currently disabled.
+=head2 do_test()
 
-=head1 EXPORT
-
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -55,7 +64,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
