@@ -4,17 +4,32 @@ use strict; use warnings;
 
 # Initialize our version
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.06';
 
-# setup our tests and etc
-use Test::Strict;
+use Test::More;
 
-# does our stuff!
 sub do_test {
+	my %MODULES = (
+		'Test::Strict'	=> '0.13',
+	);
+
+	while (my ($module, $version) = each %MODULES) {
+		eval "use $module $version";	## no critic ( ProhibitStringyEval )
+		next unless $@;
+
+		if ( $ENV{RELEASE_TESTING} ) {
+			die 'Could not load release-testing module ' . $module . " -> $@";
+		} else {
+			plan skip_all => $module . ' not available for testing';
+		}
+	}
+
 	# Set some useful stuff
+	local $Test::Strict::TEST_WARNINGS = 1;	# to silence "used only once typo warning"
 	local $Test::Strict::TEST_WARNINGS = 1;
 #	local $Test::Strict::TEST_SKIP = [ 'Build.PL', 'Makefile.PL', 'Build' ]; # TODO ineffective... need to pester T::S author to fix!
 
+	# Run the test!
 	all_perl_files_ok();
 
 	return;
@@ -28,7 +43,7 @@ Test::Apocalypse::Strict - Plugin for Test::Strict
 
 =head1 SYNOPSIS
 
-	Please do not use this module directly.
+	die "Don't use this module directly. Please use Test::Apocalypse instead.";
 
 =head1 ABSTRACT
 
@@ -36,13 +51,11 @@ Encapsulates Test::Strict functionality.
 
 =head1 DESCRIPTION
 
-Encapsulates Test::Strict functionality.
+Encapsulates Test::Strict functionality. We also enable the warnings check.
 
-We make sure that Test::Strict tests strict/warnings and exempts the Build.PL/Makefile.PL files from checks.
+=head2 do_test()
 
-=head1 EXPORT
-
-None.
+The main entry point for this plugin. Automatically called by L<Test::Apocalypse>, you don't need to know anything more :)
 
 =head1 SEE ALSO
 
@@ -56,7 +69,7 @@ Apocalypse E<lt>apocal@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Apocalypse
+Copyright 2010 by Apocalypse
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
